.. _spkg_fastjsonschema:

fastjsonschema: Fastest Python implementation of JSON schema
============================================================

Description
-----------

Fastest Python implementation of JSON schema

License
-------

BSD

Upstream Contact
----------------

https://pypi.org/project/fastjsonschema/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)

Version Information
-------------------

package-version.txt::

    2.21.1

version_requirements.txt::

    fastjsonschema

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install fastjsonschema

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i fastjsonschema

.. tab:: Alpine:

   .. CODE-BLOCK:: bash

       $ apk add py3-fastjsonschema

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S python-fastjsonschema

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install python-fastjsonschema

.. tab:: Debian/Ubuntu:

   .. CODE-BLOCK:: bash

       $ sudo apt-get install python3-fastjsonschema

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install python3-fastjsonschema

.. tab:: FreeBSD:

   .. CODE-BLOCK:: bash

       $ sudo pkg install devel/py-fastjsonschema

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/fastjsonschema

.. tab:: MacPorts:

   .. CODE-BLOCK:: bash

       $ sudo port install py-fastjsonschema

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install python-fastjsonschema

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-fastjsonschema


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
